package org.jabricks.templates;

import java.awt.*;

import javax.swing.*;
import javax.swing.border.Border;

import org.jabricks.widgets.grid.Grid;
import org.jabricks.widgets.grid.IGrid;
import org.jabricks.jpanel.ComponentParams;
import org.jabricks.jpanel.JBPanel;

import java.util.Locale;
import java.util.Properties;

public class JPanelForm extends JBPanel
{
	private static final long  serialVersionUID = 1L;
	
	private  JSplitPane     split_h;
	private  JSplitPane     split_v;
	
	private  final  int     DIVIDER_H   = 450;
	private  final  int     DIVIDER_V   = 200;
	
	private  final  String  SPLITPANE_H = "SPLITPANE_H";
	private  final  String  SPLITPANE_V = "SPLITPANE_V";

	private  IGrid          grid        = null;
	private  final  String  GRIDNAME    = "Grid";
	// типы значений в колонках таблицы
	private Class<?>[] column_classes = {
                            String.class, Integer.class,
                            Double.class, Double.class};
	// наименование колонок таблицы
	private String [] column_names = {"name", "quantity",
	                                  "price", "cost"};
	private int[]     column_width = {220, 80, 90, 90};
	// выравнивание значений в ячейках таблицы
	private Integer[] column_align = {
			                   JLabel.LEFT, JLabel.RIGHT,
	                           JLabel.RIGHT,JLabel.RIGHT};

	private String RSC = "properties/properties";
    //-----------------------------------------------------
	public JPanelForm(final JPanelActivator activator) 
	{
		super(activator);
		readComponentParams();
	}
    //-----------------------------------------------------
	private void createSplitPaneVertical()
	{
		split_v = new JSplitPane();
		split_v.setName(SPLITPANE_V);
        
		split_v.setOneTouchExpandable(false);
		split_v.setOrientation(JSplitPane.VERTICAL_SPLIT);		
		
		if (cparams.size() == 0)
			split_v.setDividerLocation(DIVIDER_V);
		else {
			ComponentParams cp;
			String          cls;
			cls = JSplitPane.class.getSimpleName();
			cp = extractComponentParams(cls, SPLITPANE_V);
			if (cp != null)
				split_v.setDividerLocation(cp.getLocation());
			else
				split_v.setDividerLocation(DIVIDER_V);
		}
		JPanel pnlTop    = new JPanel();
		JPanel pnlBottom = new JPanel();

		pnlTop   .setBackground(Color.blue );
		pnlBottom.setBackground(Color.green);

		split_v.setTopComponent   (pnlTop   );
		split_v.setBottomComponent(pnlBottom);		
	}
    //-----------------------------------------------------
	private void createSplitPaneHorizontal()
	{
		split_h = new JSplitPane();
		split_h.setName(SPLITPANE_H);
        
		split_h.setOneTouchExpandable(false);
		split_h.setOrientation(JSplitPane.HORIZONTAL_SPLIT);

		if (cparams.size() == 0)
			split_h.setDividerLocation(DIVIDER_H);
		else {
			ComponentParams cp;
			String          cls;
			cls = JSplitPane.class.getSimpleName();
			cp = extractComponentParams(cls, SPLITPANE_H);
			if (cp != null)
				split_h.setDividerLocation(cp.getLocation());
			else
				split_h.setDividerLocation(DIVIDER_H);
		}
		JPanel pnlRight = new JPanel();

		pnlRight.setLayout(new BorderLayout());
		
		split_h.setLeftComponent (grid.asWidget());
		split_h.setRightComponent(pnlRight);
	}
    //-----------------------------------------------------
	/**
	 * Метод создания интерфейса рабочей области панели
	 * @param container контейнер фрейма :
	 *                            JFrame.getContentPane()
	 */
	public void createGUI(Container container)
	{
		super.createGUI(container);

		this.setVisible(false);
		Border border;
		border = BorderFactory.createEmptyBorder(2,2,2,2);
		this.setBorder (border);

		createGrid();
    	createSplitPaneHorizontal();
		createSplitPaneVertical  ();
		
		this.add(split_h, BorderLayout.CENTER);
		
		((JPanel)split_h.getRightComponent())
                        .add(split_v, BorderLayout.CENTER);
		changeLocale (locale);
		this.setVisible(true);
	}
    //-----------------------------------------------------
    /**
     * Процедура локализации интерфейса
     * @param locale объект локализации
     */
	@Override
    public void changeLocale (Locale locale)
    {
		this.locale = locale;
		Properties props = loadProperties(RSC,locale);
		grid.setLocale(props);
    }
    //-----------------------------------------------------
    private void createGrid()
    {
        // Создание таблицы
        grid = new Grid(column_classes, column_names);
        // Определение наименования таблицы
		grid.getTable().setName(GRIDNAME);
        // Настройка таблицы
        grid.setColumnsWidth     (column_width);
        grid.setColumnsAlign     (column_align);
        grid.setReorderingAllowed(false       );

		if (cparams.size() > 0) {
			// Определение размеров колонок
			ComponentParams cp;
			String          cls;
			cls = JTable.class.getSimpleName();
			cp = extractComponentParams(cls, GRIDNAME);
			if (cp != null) {
				String columns = cp.getColumns();
				String[] cols = columns.split(SEMICOLON);
				int cnt = grid.getTable().getColumnCount();
				if (cnt == cols.length) {
					int[] cw = new int[cols.length];
					try {
						for (int i = 0; i < cols.length; i++)
							cw[i] = Integer.valueOf(cols[i]);
						grid.setColumnsWidth(cw);
					} catch (Exception e) {}
				}
			}
		}
    }
    //-----------------------------------------------------
}
